@@ -359,12 +359,25 @@ sub parse_set
   my($self) = shift;
 
   return $_[0]  if(ref $_[0] eq 'ARRAY');
-  return [ @_ ] if(@_ > 1);
+
+  if(@_ > 1 && !ref $_[1])
+  {
+    pop(@_);
+    return [ @_ ];
+  }
 
   my $val = $_[0];
 
   return undef  unless(defined $val);
 
+  my $options = ref $_[-1] eq 'HASH' ? $_[-1] : {};
+
+  no warnings 'uninitialized';
+  my $numeric = 
+    ($options->{'value_type'} =~ /^(?:(?:big)?(?:float|int(?:eger)?|num(?:eric)?)|decimal)$/) ? 1 : 0;
+
+  return undef  unless(defined $val);
+
   $val =~ s/^SET\{(.*)\}$/$1/;
 
   my @set;
@@ -372,6 +385,11 @@ sub parse_set
   while($val =~ s/(?:'((?:[^'\\]+|\\.)*)'|([^',]+))(?:,|$)//)
   {
     push(@set, (defined $1) ? $1 : $2);
+    
+    if($numeric)
+    {
+      $set[-1] =~ s/\s+//g;
+    }
   }
 
   return \@set;
@@ -1009,7 +1027,7 @@ The keywords are not case sensitive.  Any string that looks like a function call
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
