@@ -339,7 +339,7 @@ Returns a list (in list context) or reference to an array (in scalar context) of
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
